upoints.point

Package upoints :: Module point |
[hide private]
[frames] | no frames]

# Module point

point - Class for working with locations on Earth

Classes | [hide private]
| Point Simple class for representing a location on a sphere
| Points Class for representing a group of Point objects
| KeyedPoints Class for representing a keyed group of Point objects

Functions | [hide private]
`property` |
_manage_location(attr) Build managed property interface |
_dms_formatter(latitude, longitude, mode, unistr=False) Generate a human readable DM/DMS location string |

Function Details | [hide private]

### _manage_location(attr) |
Build managed property interface Parameters: `attr` (`str`) - Property's name Returns: `property` Managed property interface

### _dms_formatter(latitude, longitude, mode, unistr=False) |
Generate a human readable DM/DMS location string Parameters: `latitude` (`float`) - Location's latitude `longitude` (`float`) - Location's longitude `mode` (`str`) - Coordinate formatting system to use `unistr` (`bool`) - Whether to use extended character set